import unittest
import mock
import os
import subprocess

from modules import (
    do1handler,
    ledhandler,
    sht31handler
)

unexp_cmd = "echo 30 > /sys/class/gpio/unexport"
led_def_cmd = "echo default-on > /sys/class/leds/green/trigger"

class TestHandlers(unittest.TestCase):
    def setUp(self):
        subprocess.call(unexp_cmd, shell=True)
        subprocess.call(led_def_cmd, shell=True)

    def tearDown(self):
        subprocess.call(unexp_cmd, shell=True)
        subprocess.call(led_def_cmd, shell=True)

    def test_export(self):
        do1handler.export_do1()
        self.assertTrue(os.path.exists('/sys/class/gpio/gpio30'))

    def test_led(self):
        ledhandler.blink_led()
        self.assertTrue(os.path.exists('/sys/class/leds/green/delay_on'))
        ledhandler.blink_twice_led()
        self.assertTrue(os.path.exists('/sys/class/leds/green/invert'))

    def test_get_temp(self):
        sht31_handler = sht31handler.Sht31Handler()
        temp, RH = sht31_handler.get_temp()
        assert RH > 0
