import json
import boto3
import os

name = os.environ['THING_NAME']
alarm_name = os.environ['ALARM_NAME']

keys = ['threshold', 'hysteresys', 'period', 'alert_status']
status_val = ['ON', 'OFF']

iot = boto3.client('iot-data')
cw = boto3.client('cloudwatch')

def change_cloudwatch_alarm(threshold, enable):
    res = cw.describe_alarms(
        AlarmNames=[
            alarm_name
        ]
    )
    alarm = res['MetricAlarms'][0]
    if threshold is None:
        threshold = alarm['Threshold']

    if enable in status_val:
        if enable == 'ON':
            action_enable = True
        else:
            action_enable = False
    else:
        action_enable = alarm['ActionsEnabled']

    print('action_enable = ' + str(action_enable))
    cw.put_metric_alarm(
        AlarmName=alarm['AlarmName'],
        AlarmActions=alarm['AlarmActions'],
        ActionsEnabled=action_enable,
        MetricName=alarm['MetricName'],
        Namespace=alarm['Namespace'],
        Statistic=alarm['Statistic'],
        Period=alarm['Period'],
        EvaluationPeriods=alarm['EvaluationPeriods'],
        Threshold=threshold,
        ComparisonOperator=alarm['ComparisonOperator']
    )

def update_shadow(**kwargs):
    threshold = None
    alert_status = None
    
    dic_payload = {}
    dic_payload.setdefault('state', {})
    dic_payload['state'].setdefault('desired', {})
    for key, val in kwargs.items():
        if val is not '' and key in keys:
            if key == 'alert_status': 
                if val in status_val:
                    dic_payload['state']['desired'].setdefault(key, val)
                    alert_status = val
            elif str.isdecimal(val):
                dic_payload['state']['desired'].setdefault(key, float(val))
                if key == 'threshold':
                    threshold = float(val)
    payload = json.dumps(dic_payload)
    iot.update_thing_shadow(thingName=name, payload=payload)
    change_cloudwatch_alarm(threshold, alert_status)

def lambda_handler(event, context):
    # TODO implement
    update_shadow(**event)
    return "Success"
